.. infrastructure.rst
..
.. Project: AutoArchive
.. License: GNU GPLv3
..
.. Copyright (C) 2003 - 2015 Róbert Čerňanský



.. A section for the AutoArchive._infrastructure package.



AutoArchive._infrastructure
===========================

.. automodule:: AutoArchive._infrastructure
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   infrastructure.configuration
   infrastructure.service
   infrastructure.storage
   infrastructure.ui



Modules
-------

py_additions
^^^^^^^^^^^^

.. automodule:: AutoArchive._infrastructure.py_additions



utils
^^^^^

.. automodule:: AutoArchive._infrastructure.utils



_app_environment
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._infrastructure._app_environment



_application_context
^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._infrastructure._application_context
